@@ -7,12 +7,12 @@
 """Extractors for https://www.facebook.com/"""
 
 from .common import Extractor, Message, Dispatch
-from .. import text, exception
+from .. import text, util, exception
 from ..cache import memcache
 
 BASE_PATTERN = r"(?:https?://)?(?:[\w-]+\.)?facebook\.com"
 USER_PATTERN = (BASE_PATTERN +
-                r"/(?!media/|photo/|photo.php|watch/)"
+                r"/(?!media/|photo/|photo.php|watch/|permalink.php)"
                 r"(?:profile\.php\?id=|people/[^/?#]+/)?([^/?&#]+)")
 
 
@@ -61,6 +61,7 @@ class FacebookExtractor(Extractor):
             "user_id": text.extr(
                 set_page, '"owner":{"__typename":"User","id":"', '"'
             ),
+            "user_pfbid": "",
             "title": self.decode_all(text.extr(
                 set_page, '"title":{"text":"', '"'
             )),
@@ -74,6 +75,15 @@ class FacebookExtractor(Extractor):
             )
         }
 
+        if directory["user_id"].startswith("pfbid"):
+            directory["user_pfbid"] = directory["user_id"]
+            directory["user_id"] = (
+                text.extr(
+                    set_page, '"actors":[{"__typename":"User","id":"', '"') or
+                text.extr(
+                    set_page, '"userID":"', '"') or
+                directory["set_id"].split(".")[1])
+
         return directory
 
     def parse_photo_page(self, photo_page):
@@ -92,12 +102,13 @@ class FacebookExtractor(Extractor):
             "user_id": text.extr(
                 photo_page, '"owner":{"__typename":"User","id":"', '"'
             ),
+            "user_pfbid": "",
             "caption": self.decode_all(text.extr(
                 photo_page,
                 '"message":{"delight_ranges"',
                 '"},"message_preferred_body"'
             ).rsplit('],"text":"', 1)[-1]),
-            "date": text.parse_timestamp(
+            "date": self.parse_timestamp(
                 text.extr(photo_page, '\\"publish_time\\":', ',') or
                 text.extr(photo_page, '"created_time":', ',')
             ),
@@ -115,6 +126,11 @@ class FacebookExtractor(Extractor):
             )
         }
 
+        if photo["user_id"].startswith("pfbid"):
+            photo["user_pfbid"] = photo["user_id"]
+            photo["user_id"] = text.extr(
+                photo_page, r'\"content_owner_id_new\":\"', r'\"')
+
         text.nameext_from_url(photo["url"], photo)
 
         photo["followups_ids"] = []
@@ -156,7 +172,7 @@ class FacebookExtractor(Extractor):
             "user_id": text.extr(
                 video_page, '"owner":{"__typename":"User","id":"', '"'
             ),
-            "date": text.parse_timestamp(text.extr(
+            "date": self.parse_timestamp(text.extr(
                 video_page, '\\"publish_time\\":', ','
             )),
             "type": "video"
@@ -221,16 +237,14 @@ class FacebookExtractor(Extractor):
 
         if res.url.startswith(self.root + "/login"):
             raise exception.AuthRequired(
-                message=(f"You must be logged in to continue viewing images."
-                         f"{LEFT_OFF_TXT}")
-            )
+                message=("You must be logged in to continue viewing images." +
+                         LEFT_OFF_TXT))
 
         if b'{"__dr":"CometErrorRoot.react"}' in res.content:
             raise exception.AbortExtraction(
-                f"You've been temporarily blocked from viewing images.\n"
-                f"Please try using a different account, "
-                f"using a VPN or waiting before you retry.{LEFT_OFF_TXT}"
-            )
+                "You've been temporarily blocked from viewing images.\n"
+                "Please try using a different account, "
+                "using a VPN or waiting before you retry." + LEFT_OFF_TXT)
 
         return res
 
@@ -276,7 +290,7 @@ class FacebookExtractor(Extractor):
             else:
                 retries = 0
                 photo.update(set_data)
-                yield Message.Directory, photo
+                yield Message.Directory, "", photo
                 yield Message.Url, photo["url"], photo
 
             if not photo["next_photo_id"]:
@@ -290,27 +304,45 @@ class FacebookExtractor(Extractor):
                         "Detected a loop in the set, it's likely finished. "
                         "Extraction is over."
                     )
+            elif int(photo["next_photo_id"]) > int(photo["id"]) + i*120:
+                self.log.info(
+                    "Detected jump to the beginning of the set. (%s -> %s)",
+                    photo["id"], photo["next_photo_id"])
+                if self.config("loop", False):
+                    all_photo_ids.append(photo["next_photo_id"])
             else:
                 all_photo_ids.append(photo["next_photo_id"])
 
             i += 1
 
     @memcache(keyarg=1)
-    def _extract_profile_photos_page(self, profile):
-        profile_photos_url = f"{self.root}/{profile}/photos_by"
-
-        for _ in range(self.fallback_retries + 1):
-            profile_photos_page = self.request(profile_photos_url).text
-            if set_id := self._extract_profile_set_id(profile_photos_page):
-                break
-            self.log.debug("Got empty profile photos page, retrying...")
+    def _extract_profile(self, profile, set_id=False):
+        if set_id:
+            url = f"{self.root}/{profile}/photos_by"
         else:
-            raise exception.AbortExtraction("Failed to extract profile data")
+            url = f"{self.root}/{profile}"
+        return self._extract_profile_page(url)
 
-        avatar_page_url = text.extr(
-            profile_photos_page, ',"profilePhoto":{"url":"', '"')
+    def _extract_profile_page(self, url):
+        for _ in range(self.fallback_retries + 1):
+            page = self.request(url).text
 
-        return set_id, avatar_page_url.replace("\\/", "/")
+            if page.find('>Page Not Found</title>', 0, 3000) > 0:
+                break
+            if ('"props":{"title":"This content isn\'t available right now"' in
+                    page):
+                raise exception.AuthRequired(
+                    "authenticated cookies", "profile",
+                    "This content isn't available right now")
+
+            set_id = self._extract_profile_set_id(page)
+            user = self._extract_profile_user(page)
+            if set_id or user:
+                user["set_id"] = set_id
+                return user
+
+            self.log.debug("Got empty profile photos page, retrying...")
+        return {}
 
     def _extract_profile_set_id(self, profile_photos_page):
         set_ids_raw = text.extr(
@@ -325,6 +357,75 @@ class FacebookExtractor(Extractor):
 
         return set_id
 
+    def _extract_profile_user(self, page):
+        data = text.extr(page, '","user":{"', '},"viewer":{')
+
+        user = None
+        try:
+            user = util.json_loads(f'{{"{data}}}')
+            if user["id"].startswith("pfbid"):
+                user["user_pfbid"] = user["id"]
+                user["id"] = text.extr(page, '"userID":"', '"')
+            user["username"] = (text.extr(page, '"userVanity":"', '"') or
+                                text.extr(page, '"vanity":"', '"'))
+            user["profile_tabs"] = [
+                edge["node"]
+                for edge in (user["profile_tabs"]["profile_user"]
+                             ["timeline_nav_app_sections"]["edges"])
+            ]
+
+            if bio := text.extr(page, '"best_description":{"text":"', '"'):
+                user["biography"] = self.decode_all(bio)
+            elif (pos := page.find(
+                    '"__module_operation_ProfileCometTileView_profileT')) >= 0:
+                user["biography"] = self.decode_all(text.rextr(
+                    page, '"text":"', '"', pos))
+            else:
+                user["biography"] = text.unescape(text.remove_html(text.extr(
+                    page, "</span></span></h2>", "<ul>")))
+        except Exception:
+            if user is None:
+                self.log.debug("Failed to extract user data: %s", data)
+                user = {}
+        return user
+
+
+class FacebookPhotoExtractor(FacebookExtractor):
+    """Base class for Facebook Photo extractors"""
+    subcategory = "photo"
+    pattern = (BASE_PATTERN +
+               r"/(?:[^/?#]+/photos/[^/?#]+/|photo(?:.php)?/?\?"
+               r"(?:[^&#]+&)*fbid=)([^/?&#]+)[^/?#]*(?<!&setextract)$")
+    example = "https://www.facebook.com/photo/?fbid=PHOTO_ID"
+
+    def items(self):
+        photo_id = self.groups[0]
+        photo_url = f"{self.root}/photo/?fbid={photo_id}&set="
+        photo_page = self.photo_page_request_wrapper(photo_url).text
+
+        i = 1
+        photo = self.parse_photo_page(photo_page)
+        photo["num"] = i
+
+        set_url = f"{self.root}/media/set/?set={photo['set_id']}"
+        set_page = self.request(set_url).text
+
+        directory = self.parse_set_page(set_page)
+
+        yield Message.Directory, "", directory
+        yield Message.Url, photo["url"], photo
+
+        if self.author_followups:
+            for comment_photo_id in photo["followups_ids"]:
+                comment_photo = self.parse_photo_page(
+                    self.photo_page_request_wrapper(
+                        f"{self.root}/photo/?fbid={comment_photo_id}&set="
+                    ).text
+                )
+                i += 1
+                comment_photo["num"] = i
+                yield Message.Url, comment_photo["url"], comment_photo
+
 
 class FacebookSetExtractor(FacebookExtractor):
     """Base class for Facebook Set extractors"""
@@ -354,43 +455,6 @@ class FacebookSetExtractor(FacebookExtractor):
         return self.extract_set(set_data)
 
 
-class FacebookPhotoExtractor(FacebookExtractor):
-    """Base class for Facebook Photo extractors"""
-    subcategory = "photo"
-    pattern = (BASE_PATTERN +
-               r"/(?:[^/?#]+/photos/[^/?#]+/|photo(?:.php)?/?\?"
-               r"(?:[^&#]+&)*fbid=)([^/?&#]+)[^/?#]*(?<!&setextract)$")
-    example = "https://www.facebook.com/photo/?fbid=PHOTO_ID"
-
-    def items(self):
-        photo_id = self.groups[0]
-        photo_url = f"{self.root}/photo/?fbid={photo_id}&set="
-        photo_page = self.photo_page_request_wrapper(photo_url).text
-
-        i = 1
-        photo = self.parse_photo_page(photo_page)
-        photo["num"] = i
-
-        set_url = f"{self.root}/media/set/?set={photo['set_id']}"
-        set_page = self.request(set_url).text
-
-        directory = self.parse_set_page(set_page)
-
-        yield Message.Directory, directory
-        yield Message.Url, photo["url"], photo
-
-        if self.author_followups:
-            for comment_photo_id in photo["followups_ids"]:
-                comment_photo = self.parse_photo_page(
-                    self.photo_page_request_wrapper(
-                        f"{self.root}/photo/?fbid={comment_photo_id}&set="
-                    ).text
-                )
-                i += 1
-                comment_photo["num"] = i
-                yield Message.Url, comment_photo["url"], comment_photo
-
-
 class FacebookVideoExtractor(FacebookExtractor):
     """Base class for Facebook Video extractors"""
     subcategory = "video"
@@ -408,7 +472,7 @@ class FacebookVideoExtractor(FacebookExtractor):
         if "url" not in video:
             return
 
-        yield Message.Directory, video
+        yield Message.Directory, "", video
 
         if self.videos == "ytdl":
             yield Message.Url, "ytdl:" + video_url, video
@@ -418,6 +482,51 @@ class FacebookVideoExtractor(FacebookExtractor):
                 yield Message.Url, audio["url"], audio
 
 
+class FacebookInfoExtractor(FacebookExtractor):
+    """Extractor for Facebook Profile data"""
+    subcategory = "info"
+    directory_fmt = ("{category}", "{username}")
+    pattern = USER_PATTERN + r"/info"
+    example = "https://www.facebook.com/USERNAME/info"
+
+    def items(self):
+        user = self._extract_profile(self.groups[0])
+        return iter(((Message.Directory, "", user),))
+
+
+class FacebookAlbumsExtractor(FacebookExtractor):
+    """Extractor for Facebook Profile albums"""
+    subcategory = "albums"
+    pattern = USER_PATTERN + r"/photos_albums(?:/([^/?#]+))?"
+    example = "https://www.facebook.com/USERNAME/photos_albums"
+
+    def items(self):
+        profile, name = self.groups
+        url = f"{self.root}/{profile}/photos_albums"
+        page = self.request(url).text
+
+        pos = page.find(
+            '"TimelineAppCollectionAlbumsRenderer","collection":{"id":"')
+        if pos < 0:
+            return
+        if name is not None:
+            name = name.lower()
+
+        items = text.extract(page, '},"pageItems":', '}}},', pos)[0]
+        edges = util.json_loads(items + "}}")["edges"]
+
+        # TODO: use /graphql API endpoint
+        for edge in edges:
+            node = edge["node"]
+            album = node["node"]
+            album["title"] = title = node["title"]["text"]
+            if name is not None and name != title.lower():
+                continue
+            album["_extractor"] = FacebookSetExtractor
+            album["thumbnail"] = (img := node["image"]) and img["uri"]
+            yield Message.Queue, album["url"], album
+
+
 class FacebookPhotosExtractor(FacebookExtractor):
     """Extractor for Facebook Profile Photos"""
     subcategory = "photos"
@@ -425,7 +534,10 @@ class FacebookPhotosExtractor(FacebookExtractor):
     example = "https://www.facebook.com/USERNAME/photos"
 
     def items(self):
-        set_id = self._extract_profile_photos_page(self.groups[0])[0]
+        set_id = self._extract_profile(self.groups[0], True)["set_id"]
+        if not set_id:
+            return iter(())
+
         set_url = f"{self.root}/media/set/?set={set_id}"
         set_page = self.request(set_url).text
         set_data = self.parse_set_page(set_page)
@@ -439,7 +551,8 @@ class FacebookAvatarExtractor(FacebookExtractor):
     example = "https://www.facebook.com/USERNAME/avatar"
 
     def items(self):
-        avatar_page_url = self._extract_profile_photos_page(self.groups[0])[1]
+        user = self._extract_profile(self.groups[0])
+        avatar_page_url = user["profilePhoto"]["url"]
         avatar_page = self.photo_page_request_wrapper(avatar_page_url).text
 
         avatar = self.parse_photo_page(avatar_page)
@@ -450,7 +563,7 @@ class FacebookAvatarExtractor(FacebookExtractor):
         set_page = self.request(set_url).text
         directory = self.parse_set_page(set_page)
 
-        yield Message.Directory, directory
+        yield Message.Directory, "", directory
         yield Message.Url, avatar["url"], avatar
 
 
@@ -462,6 +575,8 @@ class FacebookUserExtractor(Dispatch, FacebookExtractor):
     def items(self):
         base = f"{self.root}/{self.groups[0]}/"
         return self._dispatch_extractors((
+            (FacebookInfoExtractor  , base + "info"),
             (FacebookAvatarExtractor, base + "avatar"),
             (FacebookPhotosExtractor, base + "photos"),
+            (FacebookAlbumsExtractor, base + "photos_albums"),
         ), ("photos",))
