@@ -102,7 +102,7 @@ BASE_PATTERN = MisskeyExtractor.update({
 class MisskeyUserExtractor(Dispatch, MisskeyExtractor):
     """Extractor for all images of a Misskey user"""
     subcategory = "user"
-    pattern = rf"{BASE_PATTERN}/@([^/?#]+)/?$"
+    pattern = BASE_PATTERN + r"/@([^/?#]+)/?$"
     example = "https://misskey.io/@USER"
 
     def items(self):
@@ -118,7 +118,7 @@ class MisskeyUserExtractor(Dispatch, MisskeyExtractor):
 class MisskeyNotesExtractor(MisskeyExtractor):
     """Extractor for a Misskey user's notes"""
     subcategory = "notes"
-    pattern = rf"{BASE_PATTERN}/@([^/?#]+)/notes"
+    pattern = BASE_PATTERN + r"/@([^/?#]+)/notes"
     example = "https://misskey.io/@USER/notes"
 
     def notes(self):
@@ -129,7 +129,7 @@ class MisskeyNotesExtractor(MisskeyExtractor):
 class MisskeyInfoExtractor(MisskeyExtractor):
     """Extractor for a Misskey user's profile data"""
     subcategory = "info"
-    pattern = rf"{BASE_PATTERN}/@([^/?#]+)/info"
+    pattern = BASE_PATTERN + r"/@([^/?#]+)/info"
     example = "https://misskey.io/@USER/info"
 
     def items(self):
@@ -140,7 +140,7 @@ class MisskeyInfoExtractor(MisskeyExtractor):
 class MisskeyAvatarExtractor(MisskeyExtractor):
     """Extractor for a Misskey user's avatar"""
     subcategory = "avatar"
-    pattern = rf"{BASE_PATTERN}/@([^/?#]+)/avatar"
+    pattern = BASE_PATTERN + r"/@([^/?#]+)/avatar"
     example = "https://misskey.io/@USER/avatar"
 
     def notes(self):
@@ -152,7 +152,7 @@ class MisskeyAvatarExtractor(MisskeyExtractor):
 class MisskeyBackgroundExtractor(MisskeyExtractor):
     """Extractor for a Misskey user's banner image"""
     subcategory = "background"
-    pattern = rf"{BASE_PATTERN}/@([^/?#]+)/ba(?:nner|ckground)"
+    pattern = BASE_PATTERN + r"/@([^/?#]+)/ba(?:nner|ckground)"
     example = "https://misskey.io/@USER/banner"
 
     def notes(self):
@@ -164,7 +164,7 @@ class MisskeyBackgroundExtractor(MisskeyExtractor):
 class MisskeyFollowingExtractor(MisskeyExtractor):
     """Extractor for followed Misskey users"""
     subcategory = "following"
-    pattern = rf"{BASE_PATTERN}/@([^/?#]+)/following"
+    pattern = BASE_PATTERN + r"/@([^/?#]+)/following"
     example = "https://misskey.io/@USER/following"
 
     def items(self):
@@ -181,7 +181,7 @@ class MisskeyFollowingExtractor(MisskeyExtractor):
 class MisskeyNoteExtractor(MisskeyExtractor):
     """Extractor for images from a Note"""
     subcategory = "note"
-    pattern = rf"{BASE_PATTERN}/notes/(\w+)"
+    pattern = BASE_PATTERN + r"/notes/(\w+)"
     example = "https://misskey.io/notes/98765"
 
     def notes(self):
@@ -191,7 +191,7 @@ class MisskeyNoteExtractor(MisskeyExtractor):
 class MisskeyFavoriteExtractor(MisskeyExtractor):
     """Extractor for favorited notes"""
     subcategory = "favorite"
-    pattern = rf"{BASE_PATTERN}/(?:my|api/i)/favorites"
+    pattern = BASE_PATTERN + r"/(?:my|api/i)/favorites"
     example = "https://misskey.io/my/favorites"
 
     def notes(self):
@@ -254,18 +254,33 @@ class MisskeyAPI():
         data["withFiles"] = False if extr.config("text-posts") else True
 
         date_min, date_max = extr._get_date_min_max()
-        if date_min is not None:
-            data["sinceDate"] = date_min * 1000
-            if date_max is None:
-                # ensure notes are returned in descending order
-                # TODO: implement 'order-posts' option
-                data["untilDate"] = (int(dt.to_ts(dt.now())) + 1000) * 1000
-        if date_max is not None:
-            data["untilDate"] = date_max * 1000
+        if (order := extr.config("order-posts")) and \
+                order[0] in ("a", "r"):
+            key = "sinceId"
+            data["sinceDate"] = 1 if date_min is None else date_min * 1000
+            date_stop = None if date_max is None else date_max
+        else:
+            key = "untilId"
+            date_stop = None
+            if date_min is not None:
+                data["sinceDate"] = date_min * 1000
+                if date_max is None:
+                    # ensure notes are returned in descending order
+                    data["untilDate"] = (int(dt.time.time()) + 1000) * 1000
+            if date_max is not None:
+                data["untilDate"] = date_max * 1000
 
         while True:
             notes = self._call(endpoint, data)
             if not notes:
                 return
-            yield from notes
-            data["untilId"] = notes[-1]["id"]
+            elif date_stop is not None and dt.to_ts(dt.parse_iso(
+                    notes[-1]["createdAt"])) > date_stop:
+                for idx, note in enumerate(notes):
+                    if dt.to_ts(dt.parse_iso(note["createdAt"])) > date_stop:
+                        yield from notes[:idx]
+                        return
+            else:
+                yield from notes
+
+            data[key] = notes[-1]["id"]
