@@ -12,6 +12,12 @@ __tests__ = (
     "#url"     : "https://postimages.org/Wtn2b3hC",
     "#category": ("imagehost", "postimg", "image"),
     "#class"   : imagehosts.PostimgImageExtractor,
+    "#results" : "https://i.postimg.cc/PhJZt1Rw/test-tesuto.png?dl=1",
+
+    "filename" : "test-テスト-\"&>",
+    "extension": "png",
+    "token"    : "Wtn2b3hC",
+    "post_url" : "https://postimg.cc/Wtn2b3hC",
 },
 
 {
@@ -30,9 +36,25 @@ __tests__ = (
     "#url"     : "https://postimg.cc/Wtn2b3hC",
     "#category": ("imagehost", "postimg", "image"),
     "#class"   : imagehosts.PostimgImageExtractor,
-    "#sha1_url"     : "72f3c8b1d6c6601a20ad58f35635494b4891a99e",
-    "#sha1_metadata": "2d05808d04e4e83e33200db83521af06e3147a84",
+    "#results"      : "https://i.postimg.cc/PhJZt1Rw/test-tesuto.png?dl=1",
     "#sha1_content" : "cfaa8def53ed1a575e0c665c9d6d8cf2aac7a0ee",
+
+    "filename" : "test-テスト-\"&>",
+    "extension": "png",
+    "token"    : "Wtn2b3hC",
+    "post_url" : "https://postimg.cc/Wtn2b3hC",
+},
+
+{
+    "#url"     : "http://postimg.org/image/5l1cogxcr/",
+    "#comment" : "no 'imagename' (#8505)",
+    "#category": ("imagehost", "postimg", "image"),
+    "#class"   : imagehosts.PostimgImageExtractor,
+    "#results" : "https://i.postimg.cc/08bm81zX/fashion-show-dream-angels-fantasy-bra-2014-adria.jpg?dl=1",
+
+    "extension": "jpg",
+    "filename" : "fashion-show-dream-angels-fantasy-bra-2014-adria",
+    "token"    : "5l1cogxcr",
 },
 
 {
@@ -41,6 +63,8 @@ __tests__ = (
     "#class"   : imagehosts.PostimgGalleryExtractor,
     "#pattern" : imagehosts.PostimgImageExtractor.pattern,
     "#count"   : 22,
+
+    "gallery_title": "My Gallery",
 },
 
 )
