@@ -40,6 +40,7 @@ class TestRange(unittest.TestCase):
     def test_parse_digit(self):
         f = self.predicate._parse
 
+        self.assertEqual(f(2), [range(2, 3)])
         self.assertEqual(f("2"), [range(2, 3)])
 
         self.assertEqual(
@@ -48,6 +49,12 @@ class TestRange(unittest.TestCase):
              range(3, 4),
              range(4, 5)],
         )
+        self.assertEqual(
+            f(["2", "3", "4"]),
+            [range(2, 3),
+             range(3, 4),
+             range(4, 5)],
+        )
 
     def test_parse_range(self):
         f = self.predicate._parse
@@ -406,89 +413,6 @@ def hash(value):
         self.assertEqual(expr(value), result)
 
 
-class TestDatetime(unittest.TestCase):
-
-    def test_to_datetime(self, f=util.to_datetime):
-
-        def _assert(value, expected):
-            result = f(value)
-            self.assertIsInstance(result, datetime.datetime)
-            self.assertEqual(result, expected, msg=repr(value))
-
-        dt = datetime.datetime(2010, 1, 1)
-        self.assertIs(f(dt), dt)
-
-        _assert(dt            , dt)
-        _assert(1262304000    , dt)
-        _assert(1262304000.0  , dt)
-        _assert(1262304000.123, dt)
-        _assert("1262304000"  , dt)
-
-        _assert("2010-01-01"                      , dt)
-        _assert("2010-01-01 00:00:00"             , dt)
-        _assert("2010-01-01T00:00:00"             , dt)
-        _assert("2010-01-01T00:00:00.123456"      , dt)
-        _assert("2009-12-31T19:00:00-05:00"       , dt)
-        _assert("2009-12-31T19:00:00.123456-05:00", dt)
-        _assert("2010-01-01T00:00:00Z"            , dt)
-        _assert("2010-01-01T00:00:00.123456Z"     , dt)
-
-        _assert(0    , util.EPOCH)
-        _assert(""   , util.EPOCH)
-        _assert("foo", util.EPOCH)
-        _assert(None , util.EPOCH)
-        _assert(()   , util.EPOCH)
-        _assert([]   , util.EPOCH)
-        _assert({}   , util.EPOCH)
-        _assert((1, 2, 3), util.EPOCH)
-
-    @unittest.skipIf(sys.hexversion < 0x30b0000,
-                     "extended fromisoformat timezones")
-    def test_to_datetime_tz(self, f=util.to_datetime):
-
-        def _assert(value, expected):
-            result = f(value)
-            self.assertIsInstance(result, datetime.datetime)
-            self.assertEqual(result, expected, msg=repr(value))
-
-        dt = datetime.datetime(2010, 1, 1)
-
-        _assert("2009-12-31T19:00:00-05"          , dt)
-        _assert("2009-12-31T19:00:00-0500"        , dt)
-        _assert("2009-12-31T19:00:00.123456-05"   , dt)
-        _assert("2009-12-31T19:00:00.123456-0500" , dt)
-
-    def test_datetime_to_timestamp(self, f=util.datetime_to_timestamp):
-        self.assertEqual(f(util.EPOCH), 0.0)
-        self.assertEqual(f(datetime.datetime(2010, 1, 1)), 1262304000.0)
-        self.assertEqual(f(datetime.datetime(2010, 1, 1, 0, 0, 0, 128000)),
-                         1262304000.128000)
-        with self.assertRaises(TypeError):
-            f(None)
-
-    def test_datetime_to_timestamp_string(
-            self, f=util.datetime_to_timestamp_string):
-        self.assertEqual(f(util.EPOCH), "0")
-        self.assertEqual(f(datetime.datetime(2010, 1, 1)), "1262304000")
-        self.assertEqual(f(None), "")
-
-    def test_datetime_from_timestamp(
-            self, f=util.datetime_from_timestamp):
-        self.assertEqual(f(0.0), util.EPOCH)
-        self.assertEqual(f(1262304000.0), datetime.datetime(2010, 1, 1))
-        self.assertEqual(f(1262304000.128000).replace(microsecond=0),
-                         datetime.datetime(2010, 1, 1, 0, 0, 0))
-
-    def test_datetime_utcfromtimestamp(
-            self, f=util.datetime_utcfromtimestamp):
-        self.assertEqual(f(0.0), util.EPOCH)
-        self.assertEqual(f(1262304000.0), datetime.datetime(2010, 1, 1))
-
-    def test_datetime_utcnow(
-            self, f=util.datetime_utcnow):
-        self.assertIsInstance(f(), datetime.datetime)
-
-
 class TestOther(unittest.TestCase):
 
     def test_bencode(self):
